==> ogre-docs-1.12.1-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_default_hardware_buffer_manager.js <==
var class_ogre_1_1_default_hardware_buffer_manager =
[
    [ "BufferLicenseType", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08fa", [
      [ "BLT_MANUAL_RELEASE", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08faa372ccf538e8a6022bba092d2b47f4fdb", null ],
      [ "BLT_AUTOMATIC_RELEASE", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08faa994cf0191de83556e3c1e6cf30cd6acb", null ]
    ] ],
    [ "DefaultHardwareBufferManager", "class_ogre_1_1_default_hardware_buffer_manager.html#a4cd035da8caa2867d327ea9490f91c4d", null ],
    [ "createVertexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#afc4b33f07c23045e13db48baae0e6dc4", null ],
    [ "createIndexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a1058293f89bf34bcfacff9b122944ccf", null ],
    [ "createRenderToVertexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a1485b66a2e3a8679a0681d527ff2349a", null ],
    [ "createUniformBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#aa1b7898f96fbfaa36c7244e0105e0890", null ],
    [ "createCounterBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a0cce075405b6e83335acc40c4d13097b", null ],
    [ "getSingleton", "class_ogre_1_1_default_hardware_buffer_manager.html#a380063fef4a4563c90d45a03ac196dc7", null ],
    [ "getSingletonPtr", "class_ogre_1_1_default_hardware_buffer_manager.html#ab633b90f5015dc3199f96e0514347b3b", null ],
    [ "createVertexDeclaration", "class_ogre_1_1_default_hardware_buffer_manager.html#abe3ea209174c3a40286dde425addb814", null ],
    [ "destroyVertexDeclaration", "class_ogre_1_1_default_hardware_buffer_manager.html#ae3b729879133ff816e15f73e921c3b18", null ],
    [ "createVertexBufferBinding", "class_ogre_1_1_default_hardware_buffer_manager.html#acbde393716ec1057024cdff4d3282913", null ],
    [ "destroyVertexBufferBinding", "class_ogre_1_1_default_hardware_buffer_manager.html#a7c2868897d9a417b523f2fe9420f1e22", null ],
    [ "registerVertexBufferSourceAndCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#a1deff999bf2f7fa437609fca417810e9", null ],
    [ "allocateVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#a557fa7f938bee48841e21e995eb095d6", null ],
    [ "releaseVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#acca9ea14315ef17d74f6ab972d9a1ec8", null ],
    [ "touchVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#ab717df387ec6c1e119ed2ac0e2c9a54b", null ],
    [ "_freeUnusedBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a01c05c63b98f45df312660e724d95320", null ],
    [ "_releaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a5551674a13abf8d3458d2798e58d7cd9", null ],
    [ "_forceReleaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a876ce18832783cd168f4e55d989c3f1c", null ],
    [ "_forceReleaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a8cd2588a1b57f4b417d6816f7ddb5584", null ],
    [ "_notifyVertexBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#a29b2e243bab8522ae27ec23268ea154a", null ],
    [ "_notifyIndexBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#aa12ae6a67af715b2be80182bd05abb46", null ],
    [ "_notifyUniformBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#ad19793152eef356380827edb755c613e", null ],
    [ "_notifyCounterBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#a45fe3ad0964310d9b150d45eaddf67d3", null ]
];

==> ogre-docs-1.12.2-2-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_default_hardware_buffer_manager.js <==
var class_ogre_1_1_default_hardware_buffer_manager =
[
    [ "BufferLicenseType", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08fa", [
      [ "BLT_MANUAL_RELEASE", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08faa372ccf538e8a6022bba092d2b47f4fdb", null ],
      [ "BLT_AUTOMATIC_RELEASE", "class_ogre_1_1_default_hardware_buffer_manager.html#a88f21df1e7ee330033812ddeba4a08faa994cf0191de83556e3c1e6cf30cd6acb", null ]
    ] ],
    [ "DefaultHardwareBufferManager", "class_ogre_1_1_default_hardware_buffer_manager.html#a4cd035da8caa2867d327ea9490f91c4d", null ],
    [ "~DefaultHardwareBufferManager", "class_ogre_1_1_default_hardware_buffer_manager.html#a222290dca734e3cb879691b334776e34", null ],
    [ "createVertexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#afc4b33f07c23045e13db48baae0e6dc4", null ],
    [ "createIndexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a1058293f89bf34bcfacff9b122944ccf", null ],
    [ "createRenderToVertexBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a1485b66a2e3a8679a0681d527ff2349a", null ],
    [ "createUniformBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#aa1b7898f96fbfaa36c7244e0105e0890", null ],
    [ "createCounterBuffer", "class_ogre_1_1_default_hardware_buffer_manager.html#a0cce075405b6e83335acc40c4d13097b", null ],
    [ "getSingleton", "class_ogre_1_1_default_hardware_buffer_manager.html#a380063fef4a4563c90d45a03ac196dc7", null ],
    [ "getSingletonPtr", "class_ogre_1_1_default_hardware_buffer_manager.html#ab633b90f5015dc3199f96e0514347b3b", null ],
    [ "createVertexDeclaration", "class_ogre_1_1_default_hardware_buffer_manager.html#abe3ea209174c3a40286dde425addb814", null ],
    [ "destroyVertexDeclaration", "class_ogre_1_1_default_hardware_buffer_manager.html#ae3b729879133ff816e15f73e921c3b18", null ],
    [ "createVertexBufferBinding", "class_ogre_1_1_default_hardware_buffer_manager.html#acbde393716ec1057024cdff4d3282913", null ],
    [ "destroyVertexBufferBinding", "class_ogre_1_1_default_hardware_buffer_manager.html#a7c2868897d9a417b523f2fe9420f1e22", null ],
    [ "registerVertexBufferSourceAndCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#a1deff999bf2f7fa437609fca417810e9", null ],
    [ "allocateVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#a557fa7f938bee48841e21e995eb095d6", null ],
    [ "releaseVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#acca9ea14315ef17d74f6ab972d9a1ec8", null ],
    [ "touchVertexBufferCopy", "class_ogre_1_1_default_hardware_buffer_manager.html#ab717df387ec6c1e119ed2ac0e2c9a54b", null ],
    [ "_freeUnusedBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a01c05c63b98f45df312660e724d95320", null ],
    [ "_releaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a5551674a13abf8d3458d2798e58d7cd9", null ],
    [ "_forceReleaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a876ce18832783cd168f4e55d989c3f1c", null ],
    [ "_forceReleaseBufferCopies", "class_ogre_1_1_default_hardware_buffer_manager.html#a8cd2588a1b57f4b417d6816f7ddb5584", null ],
    [ "_notifyVertexBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#a29b2e243bab8522ae27ec23268ea154a", null ],
    [ "_notifyIndexBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#aa12ae6a67af715b2be80182bd05abb46", null ],
    [ "_notifyUniformBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#ad19793152eef356380827edb755c613e", null ],
    [ "_notifyCounterBufferDestroyed", "class_ogre_1_1_default_hardware_buffer_manager.html#a45fe3ad0964310d9b150d45eaddf67d3", null ]
];
